/*
---------------------------------------------------------------------------
Open Asset Import Library (assimp)
---------------------------------------------------------------------------

Copyright (c) 2006-2022, assimp team

All rights reserved.

Redistribution and use of this software in source and binary forms,
with or without modification, are permitted provided that the following
conditions are met:

* Redistributions of source code must retain the above
copyright notice, this list of conditions and the
following disclaimer.

* Redistributions in binary form must reproduce the above
copyright notice, this list of conditions and the
following disclaimer in the documentation and/or other
materials provided with the distribution.

* Neither the name of the assimp team, nor the names of its
contributors may be used to endorse or promote products
derived from this software without specific prior
written permission of the assimp team.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
---------------------------------------------------------------------------
*/

#pragma once
#ifndef AI_AABB_H_INC
#define AI_AABB_H_INC

#ifdef __GNUC__
#pragma GCC system_header
#endif

#include <assimp/vector3.h>

// ---------------------------------------------------------------------------
/** 
 *  An axis-aligned bounding box.  
 */
struct aiAABB {
    C_STRUCT aiVector3D mMin;
    C_STRUCT aiVector3D mMax;

#ifdef __cplusplus
    /// @brief The default class constructor.
    aiAABB() :
            mMin(), mMax() {
        // empty
    }

    /// @brief The class constructor with the minimum and maximum.
    /// @param min  The minimum dimension.
    /// @param max  The maximum dimension.
    aiAABB(const aiVector3D &min, const aiVector3D &max) :
            mMin(min), mMax(max) {
        // empty
    }

    ///	@brief  The class destructor.
    ~aiAABB() = default;

#endif // __cplusplus
};

#endif // AI_AABB_H_INC
